<?php
/**
 * Simple Machines Forum (SMF)
 *
 * @package SMF
 * @author Simple Machines https://www.simplemachines.org
 * @copyright 2022 Simple Machines and individual contributors
 * @license https://www.simplemachines.org/about/smf/license.php BSD
 *
 * @version 2.1.0
 */

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	https://www.simplemachines.org/

	2.1 feather by https://www.idesignSMF.com
*/

/**
 * Initialize the template... mainly little settings.
 */
function template_init()
{
	global $settings, $txt;

	/* $context, $options and $txt may be available for use, but may not be fully populated yet. */

	// The version this template/theme is for. This should probably be the version of SMF it was created for.
	$settings['theme_version'] = '2.1';

	// Set the following variable to true if this theme requires the optional theme strings file to be loaded.
	$settings['require_theme_strings'] = true;

	// Set the following variable to true if this theme wants to display the avatar of the user that posted the last and the first post on the message index and recent pages.
	$settings['avatars_on_indexes'] = true;

	// Set the following variable to true if this theme wants to display the avatar of the user that posted the last post on the board index.
	$settings['avatars_on_boardIndex'] = true;

	// Set the following variable to true if this theme wants to display the login and register buttons in the main forum menu.
	$settings['login_main_menu'] = false;

	// This defines the formatting for the page indexes used throughout the forum.
	$settings['page_index'] = array(
		'extra_before' => '<span class="pages">' . $txt['pages'] . '</span>',
		'previous_page' => '<span class="main_icons previous_page"></span>',
		'current_page' => '<span class="current_page">%1$d</span> ',
		'page' => '<a class="nav_page" href="{URL}">%2$s</a> ',
		'expand_pages' => '<span class="expand_pages" onclick="expandPages(this, {LINK}, {FIRST_PAGE}, {LAST_PAGE}, {PER_PAGE});"> ... </span>',
		'next_page' => '<span class="main_icons next_page"></span>',
		'extra_after' => '',
	);

	// Allow css/js files to be disabled for this specific theme.
	// Add the identifier as an array key. IE array('smf_script'); Some external files might not add identifiers, on those cases SMF uses its filename as reference.
	if (!isset($settings['disable_files']))
		$settings['disable_files'] = array();
}

/**
 * The main sub template above the content.
 */
function template_html_above()
{
	global $context, $scripturl, $txt, $modSettings;

	// Show right to left, the language code, and the character set for ease of translating.
	echo '<!DOCTYPE html>
<html', $context['right_to_left'] ? ' dir="rtl"' : '', !empty($txt['lang_locale']) ? ' lang="' . str_replace("_", "-", substr($txt['lang_locale'], 0, strcspn($txt['lang_locale'], "."))) . '"' : '', '>
<head>
	<meta charset="', $context['character_set'], '">';

	/*
		You don't need to manually load index.css, this will be set up for you.
		Note that RTL will also be loaded for you.
		To load other CSS and JS files you should use the functions
		loadCSSFile() and loadJavaScriptFile() respectively.
		This approach will let you take advantage of SMF's automatic CSS
		minimization and other benefits. You can, of course, manually add any
		other files you want after template_css() has been run.

	*	Short example:
			- CSS: loadCSSFile('filename.css', array('minimize' => true));
			- JS:  loadJavaScriptFile('filename.js', array('minimize' => true));
			You can also read more detailed usages of the parameters for these
			functions on the SMF wiki.

	*	Themes:
			The most efficient way of writing multi themes is to use a master
			index.css plus variant.css files. If you've set them up properly
			(through $settings['theme_variants']), the variant files will be loaded
			for you automatically.
			Additionally, tweaking the CSS for the editor requires you to include
			a custom 'jquery.sceditor.theme.css' file in the css folder if you need it.

	*	MODs:
			If you want to load CSS or JS files in here, the best way is to use the
			'integrate_load_theme' hook for adding multiple files, or using
			'integrate_pre_css_output', 'integrate_pre_javascript_output' for a single file.
	*/

	// load in any css from mods or themes so they can overwrite if wanted
	loadCSSFile('https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@5/css/all.min.css', array('external' => true));
	loadCSSFile('https://cdnjs.cloudflare.com/ajax/libs/normalize/8.0.1/normalize.min.css', array('external' => true));
	template_css();
	
	// load in any javascript files from mods and themes
	loadJavaScriptFile('https://cdnjs.cloudflare.com/ajax/libs/jquery/3.2.1/jquery.min.js', array('external' => true));
	loadJavaScriptFile('https://cdn.rawgit.com/VPenkov/okayNav/master/app/js/jquery.okayNav.js', array('external' => true));
	loadJavaScriptFile('child_box.js', array('minimize' => true));
	template_javascript();

	echo '
	<title>', $context['page_title_html_safe'], '</title>
	<meta name="viewport" content="width=device-width, initial-scale=1">';

	// Content related meta tags, like description, keywords, Open Graph stuff, etc...
	foreach ($context['meta_tags'] as $meta_tag)
	{
		echo '
	<meta';

		foreach ($meta_tag as $meta_key => $meta_value)
			echo ' ', $meta_key, '="', $meta_value, '"';

		echo '>';
	}

	/*	What is your Lollipop's color?
		Theme Authors, you can change the color here to make sure your theme's main color gets visible on tab */
	echo '
	<meta name="theme-color" content="#f8f8f8">';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex">';

	// Present a canonical url for search engines to prevent duplicate content in their indices.
	if (!empty($context['canonical_url']))
		echo '
	<link rel="canonical" href="', $context['canonical_url'], '">';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help">
	<link rel="contents" href="', $scripturl, '">', ($context['allow_search'] ? '
	<link rel="search" href="' . $scripturl . '?action=search">' : '');

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['rss'], '" href="', $scripturl, '?action=.xml;type=rss2', !empty($context['current_board']) ? ';board=' . $context['current_board'] : '', '">
	<link rel="alternate" type="application/atom+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['atom'], '" href="', $scripturl, '?action=.xml;type=atom', !empty($context['current_board']) ? ';board=' . $context['current_board'] : '', '">';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['links']['next']))
		echo '
	<link rel="next" href="', $context['links']['next'], '">';

	if (!empty($context['links']['prev']))
		echo '
	<link rel="prev" href="', $context['links']['prev'], '">';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0">';

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'];

	echo '
</head>
<body id="', $context['browser_body_id'], '" class="action_', !empty($context['current_action']) ? $context['current_action'] : (!empty($context['current_board']) ?
		'messageindex' : (!empty($context['current_topic']) ? 'display' : 'home')), !empty($context['current_board']) ? ' board_' . $context['current_board'] : '', '">
<div id="footerfix">';
}

/**
 * The upper part of the main template layer. This is the stuff that shows above the main forum content.
 */
function template_body_above()
{
	global $context, $settings, $scripturl, $txt, $modSettings, $maintenance, $options, $topic, $board;

	// Wrapper div now echoes permanently for better layout options. h1 a is now target for "Go up" links.
	echo '
<div id="wrapper-bg"></div>
<div id="wrapper-outer">
	<div id="wrapper">';

	echo '
	<div id="header">
            <h1 class="forumtitle">             
                <a id="top" href="', $scripturl, '">';

                if(!empty($settings['ft_icon'])) {
                echo ' <span style="color:', $settings['ft_icon_color'] , '">', $settings['ft_icon'] , '</span>';
                           }
                echo ' ', empty($context['header_logo_url_html_safe']) ? $context['forum_name_html_safe'] : '<img src="' . $context['header_logo_url_html_safe'] . '" alt="' . $context['forum_name_html_safe'] . '">', '</a>
            </h1>';

    echo '
			<div role="navigation" id="nav-main" class="okayNav">
				<ul class="reset">';
				if(!empty($settings['top_link_name_1']))
				echo '
					<li><a href="', $settings['top_link_1'] , '">' , $settings['top_link_name_1'] , '</a></li>';

				if(!empty($settings['top_link_name_2']))
				echo '
					<li><a href="', $settings['top_link_2'] , '">' , $settings['top_link_name_2'] , '</a></li>';

				if(!empty($settings['top_link_name_3']))
				echo '
					<li><a href="', $settings['top_link_3'] , '">' , $settings['top_link_name_3'] , '</a></li>';

				if(!empty($settings['top_link_name_4']))
				echo '
					<li><a href="', $settings['top_link_4'] , '">' , $settings['top_link_name_4'] , '</a></li>';

				if(!empty($settings['top_link_name_5']))
				echo '
					<li><a href="', $settings['top_link_5'] , '" target="_blank">' , $settings['top_link_name_5'] , '</a></li>';

				if(!empty($settings['top_link_name_6']))
				echo '
					<li><a href="', $settings['top_link_6'] , '" target="_blank">' , $settings['top_link_name_6'] , '</a></li>';
                echo'
				</ul>
		    </div>		
	</div><!-- #header -->';

    echo '
    <div id="bar">
            <div class="nav"><a id="resp-menu" class="responsive-menu" href="#"><i class="fas fa-bars"></i></a> ', template_menu(), '</div>
    </div><!-- #bar -->';
			
	// The main content should go here.
	echo '
	<div id="content_section">
	<div class="sidebar s2">
			<ul class="user-links">';
			
	// Otherwise they're a guest. Ask them to either register or login.
	    if ($context['user']['is_guest'])
	        {
	echo '
		        <li><a class="user-tooltip" href="', $scripturl, '?action=signup" title="', $txt['sign_up'], '"> <i class="fas fa-user-plus"></i></a></li>
		        <li><a class="user-tooltip" href="', $scripturl, '?action=login" title="', $txt['login'], '"> <i class="fas fa-sign-in-alt"></i></a></li>';
			}

				// If the user is logged in, display some things that might be useful.
	    if ($context['user']['is_logged'])
	        {
	echo '
				<li><a class="user-tooltip" href="', $scripturl, '?action=unread" title="', $txt['unread_since_visit'], '"> <i class="fas fa-star"></i></a></li>
		        <li><a class="user-tooltip" href="', $scripturl, '?action=unreadreplies" title="', $txt['show_unread_replies'], '"> <i class="fas fa-bullhorn"></i></a></li>';

		// Secondly, PMs if we're doing them
		if ($context['allow_pm'])
	echo '
				<li><a class="user-tooltip" href="', $scripturl, '?action=profile" title="', $txt['profile'], '"><i class="fas fa-user"></i></a></li>
				<li><a class="user-tooltip" href="', $scripturl, '?action=pm" title="', $txt['personal_messages'], '"><i class="fas fa-envelope-open"></i>', !empty($context['user']['unread_messages']) ? ' <span class="amt">' . $context['user']['unread_messages'] . '</span>' : '', '</a></li>
				<li><a class="user-tooltip" href="', $scripturl, '?action=profile;area=showalerts;u=', $context['user']['id'], '" title="', $txt['alerts'], '"><i class="fas fa-bell"></i>', !empty($context['user']['alerts']) ? ' <span class="amt">' . $context['user']['alerts'] . '</span>' : '', '</a></li>
				<li><a class="user-tooltip" href="', $scripturl, '?action=logout;', $context['session_var'], '=', $context['session_id'], '" title="', $txt['sign_out'], '"><i class="fas fa-sign-out-alt"></i></a></li>';
			}
	echo '
			    <li><div class="user-tooltip open_child" title="', $txt['sub_boards2'], '"><i class="fas fa-plus-circle"></i></div>';
	echo '			
			</ul>
	</div><!-- .sidebar s2-->
	<div class="clear"></div>';

    echo '
		<div id="main_content_section">';

	if (!empty($settings['hero_index'])) {
		if (empty($_REQUEST['action']) && (empty($topic)) && (empty($board)))
			$hero = 1; else $hero = 0; } else $hero = 1;
	
	    if (!empty($settings['enable_hero']) && $hero == 1)
	{
	echo '
		<div class="blog-card-outer">';
                if(!empty($settings['hero_img']))
                echo '
                    <div class="hero" style="background-image: url(', $settings['hero_img'] , ')">';
                if(!empty($settings['hero_title']))
                echo '
                             <h1>', $settings['hero_title'] , '</h1>';

                if(!empty($settings['hero_description']))
                echo '
                             <p>', $settings['hero_description'] , '</p>';

                if(!empty($settings['hero_url']))
                echo '
                             <a class="hero-button" href="', $settings['hero_url'] , '">', $txt['read_more'], '</a>';
                echo '
                    </div>
        </div><!-- .blog_card_outer -->';
    }

			// Show a random news item? (or you could pick one from news_lines...)
			if (!empty($settings['enable_news']) && !empty($context['random_news_line']))
			
	echo '
			<div class="news2">
				<h2>', $txt['news2'], ': </h2>
				<p>', $context['random_news_line'], '</p>';
	echo '
			</div><!-- .news2 -->';
       
	echo '
			<div class="blog-card-outer">';
}

/**
 * The stuff shown immediately below the main content, including the footer
 */
function template_body_below()
{
	global $context, $txt, $settings, $scripturl, $modSettings;

	echo '

	        </div><!-- .blog-card-outer -->';

     echo'
	<div class="social-font-awesome">';
				if(!empty($settings['facebook_url']))
				echo '
		                <a href="', $settings['facebook_url'] , '"><i class="fab fa-facebook"></i></a>';

				if(!empty($settings['twitter_url']))
				echo '
		                <a href="', $settings['twitter_url'] , '"><i class="fab fa-twitter"></i></a>';

				if(!empty($settings['youtube_url']))
				echo '
		                <a href="', $settings['youtube_url'] , '"><i class="fab fa-youtube"></i></a>';

				if(!empty($settings['linkedin_url']))
				echo '
		                <a href="', $settings['linkedin_url'] , '"><i class="fab fa-linkedin"></i></a>';

				if(!empty($settings['rss_url']))
				echo '
		                <a href="', $settings['rss_url'] , '"><i class="fas fa-rss"></i></a>';
			    echo '
	</div><!-- .social-font-awesome -->';
    echo '

		</div><!-- #main_content_section -->
	</div><!-- #content_section -->';

	echo '
	</div><!-- #wrapper -->
</div><!-- #wrapper-outer -->
</div><!-- #footerfix -->';

if (!empty($settings['fmenu_enabled']))
{
    echo '
<div class="footer">
    <div class="footer-container">
        <div class="footer-main">
            <div class="footer_article">
                <ul>';
			if(!empty($settings['fmenu_heading1']))
				echo '
                    <li><h3>', $settings['fmenu_heading1'] , '</h3></li>';
			if(!empty($settings['fmenu_title1']))
				echo '
                    <li><a title="' . $settings['fmenu_title1'] . '" href="', $settings['fmenu_url1'] , '">' , $settings['fmenu_title1'] , '</a></li>';
			if(!empty($settings['fmenu_title2']))
				echo '
                    <li><a title="' . $settings['fmenu_title2'] . '" href="', $settings['fmenu_url2'] , '">' , $settings['fmenu_title2'] , '</a></li>';
			if(!empty($settings['fmenu_title3']))
				echo '
                    <li><a title="' . $settings['fmenu_title3'] . '" href="', $settings['fmenu_url3'] , '">' , $settings['fmenu_title3'] , '</a></li>';
			if(!empty($settings['fmenu_title4']))
				echo '
                    <li><a title="' . $settings['fmenu_title4'] . '" href="', $settings['fmenu_url4'] , '">' , $settings['fmenu_title4'] , '</a></li>';
                echo '
                </ul>
            </div>
            <div class="footer_article">
                <ul>';
			if(!empty($settings['fmenu_heading2']))
				echo '
                    <li><h3>', $settings['fmenu_heading2'] , '</h3></li>';
			if(!empty($settings['fmenu_title5']))
				echo '
                    <li><a title="' . $settings['fmenu_title5'] . '" href="', $settings['fmenu_url5'] , '">' , $settings['fmenu_title5'] , '</a></li>';
			if(!empty($settings['fmenu_title6']))
				echo '
                    <li><a title="' . $settings['fmenu_title6'] . '" href="', $settings['fmenu_url6'] , '">' , $settings['fmenu_title6'] , '</a></li>';
			if(!empty($settings['fmenu_title7']))
				echo '
                    <li><a title="' . $settings['fmenu_title7'] . '" href="', $settings['fmenu_url7'] , '">' , $settings['fmenu_title7'] , '</a></li>';
			if(!empty($settings['fmenu_title8']))
				echo '
                    <li><a title="' . $settings['fmenu_title8'] . '" href="', $settings['fmenu_url8'] , '">' , $settings['fmenu_title8'] , '</a></li>';
                echo '
                </ul>
            </div>
            <div class="footer_article">
                <ul>';
			if(!empty($settings['fmenu_heading3']))
				echo '
                    <li><h3>', $settings['fmenu_heading3'] , '</h3></li>';
			if(!empty($settings['fmenu_title9']))
				echo '
                    <li><a title="' . $settings['fmenu_title9'] . '" href="', $settings['fmenu_url9'] , '">' , $settings['fmenu_title9'] , '</a></li>';
			if(!empty($settings['fmenu_title10']))
				echo '
                    <li><a title="' . $settings['fmenu_title10'] . '" href="', $settings['fmenu_url10'] , '">' , $settings['fmenu_title10'] , '</a></li>';
			if(!empty($settings['fmenu_title11']))
				echo '
                    <li><a title="' . $settings['fmenu_title11'] . '" href="', $settings['fmenu_url11'] , '">' , $settings['fmenu_title11'] , '</a></li>';
			if(!empty($settings['fmenu_title12']))
				echo '
                    <li><a title="' . $settings['fmenu_title12'] . '" href="', $settings['fmenu_url2'] , '">' , $settings['fmenu_title12'] , '</a></li>';
                echo '
                </ul>
            </div>
            <div class="footer_article">
                <ul>';
			if(!empty($settings['fmenu_heading4']))
				echo '
                    <li><h3>', $settings['fmenu_heading4'] , '</h3></li>';
			if(!empty($settings['fmenu_title13']))
				echo '
                    <li><p>', $settings['fmenu_title13'] , '</p></li>';
                echo '
                </ul>
            </div>
        </div>
    </div>
</div><!-- @end .footer footer Links -->';

}

	// Show the footer with copyright, terms and help links.
	echo '
<div id="footer">
	<div class="inner_wrap">';

	// There is now a global "Go to top" link at the right.
	echo '
		<ul>
			<li class="floatright"><a href="', $scripturl, '?action=help">', $txt['help'], '</a> ', (!empty($modSettings['requireAgreement'])) ? '| <a href="' . $scripturl . '?action=agreement">' . $txt['terms_and_rules'] . '</a>' : '', ' | <a href="#">', $txt['go_up'], ' &#9650;</a></li>
			<li class="copyright">', theme_copyright(), ' | ', idesign_copyright(), '</li>
		</ul>';

	// Show the load time?
	if ($context['show_load_time'])
	echo '
		<p>', sprintf($txt['page_created_full'], $context['load_time'], $context['load_queries']), '</p>';

	echo '
	</div><!-- .inner_wrap -->
</div><!-- #footer -->';

}

/**
 * This shows any deferred JavaScript and closes out the HTML
 */
function template_html_below()
{
	// Load in any javascipt that could be deferred to the end of the page
	template_javascript(true);

	echo '
	<script>
      	    $(document).ready(function(){ 
            	var touch 	= $("#resp-menu");
             	var menu 	= $(".menu");
 
	        $(touch).on("click", function(e) {
	        	e.preventDefault();
		        menu.slideToggle();
	        });
	
	        $(window).resize(function(){
		        var w = $(window).width();
		        if(w > 767 && menu.is(":hidden")) {
			    menu.removeAttr("style");
		        }
	         });	
            });
    </script>

	<script>
	   var navigation = $(\'#nav-main\').okayNav({
			parent : \'\', // will call nav\'s parent() by default
		    toggle_icon_class : \'okayNav__menu-toggle\',
		    toggle_icon_content: \'<span /><span /><span />\',
 		    align_right: true, // If false, the menu and the kebab icon will be on the left
 		    swipe_enabled: false, // If true, you\'ll be able to swipe left/right to open the navigation
		    threshold: 50, // Nav will auto open/close if swiped >= this many percent
		    beforeOpen : function() {}, // Will trigger before the nav gets opened
		    afterOpen : function() {}, // Will trigger after the nav gets opened
		    beforeClose : function() {}, // Will trigger before the nav gets closed
		    afterClose : function() {}, // Will trigger after the nav gets closed
		    itemHidden: function() {}, // Will trigger after an item moves to the hidden navigation
 		    itemDisplayed: function() {} // Will trigger after an item moves to the visible navigation
           });
	</script>

</body>
</html>';
}

/**
 * Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
 *
 * @param bool $force_show Whether to force showing it even if settings say otherwise
 */
function theme_linktree($force_show = false)
{
	global $context, $shown_linktree, $scripturl, $txt;

	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	echo '
				<div class="navigate_section">
					<ul>';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		echo '
						<li', ($link_num == count($context['linktree']) - 1) ? ' class="last"' : '', '>';

		// Don't show a separator for the first one.
		// Better here. Always points to the next level when the linktree breaks to a second line.
		// Picked a better looking HTML entity, and added support for RTL plus a span for styling.
		if ($link_num != 0)
			echo '
							<span class="dividers">', $context['right_to_left'] ? ' &#9668; ' : ' &#9658; ', '</span>';

		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'], ' ';

		// Show the link, including a URL if it should have one.
		if (isset($tree['url']))
			echo '
							<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>';
		else
			echo '
							<span>' . $tree['name'] . '</span>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo ' ', $tree['extra_after'];

		echo '
						</li>';
	}

	echo '
					</ul>
				</div><!-- .navigate_section -->';

	$shown_linktree = true;
}

// idesignSMF.com theme copyright
function idesign_copyright() {
	$idesign = '<a href="https://www.idesignsmf.com" title="Free Responsive SMF Themes" target="_blank" rel="noopener">idesignSMF</a>';

	return $idesign;
}

/**
 * Show the menu up top. Something like [home] [help] [profile] [logout]...
 */
function template_menu()
{
	global $context;

	echo '
                <div class="nav">
					<ul class="menu">';

	// Note: Menu markup has been cleaned up to remove unnecessary spans and classes.
	foreach ($context['menu_buttons'] as $act => $button)
	{
		echo '
						<li class="button_', $act, '', !empty($button['sub_buttons']) ? ' subsections"' : '"', '>
							<a', $button['active_button'] ? ' class="active"' : '', ' href="', $button['href'], '"', isset($button['target']) ? ' target="' . $button['target'] . '"' : '', isset($button['onclick']) ? ' onclick="' . $button['onclick'] . '"' : '', '>
								', $button['icon'], '<span class="textmenu">', $button['title'], !empty($button['amt']) ? ' <span class="amt">' . $button['amt'] . '</span>' : '', '</span>
							</a>';

		// 2nd level menus
		if (!empty($button['sub_buttons']))
		{
			echo '
							<ul>';

			foreach ($button['sub_buttons'] as $childbutton)
			{
				echo '
								<li', !empty($childbutton['sub_buttons']) ? ' class="subsections"' : '', '>
									<a href="', $childbutton['href'], '"', isset($childbutton['target']) ? ' target="' . $childbutton['target'] . '"' : '', isset($childbutton['onclick']) ? ' onclick="' . $childbutton['onclick'] . '"' : '', '>
										', $childbutton['title'], !empty($childbutton['amt']) ? ' <span class="amt">' . $childbutton['amt'] . '</span>' : '', '
									</a>';
				// 3rd level menus :)
				if (!empty($childbutton['sub_buttons']))
				{
					echo '
									<ul>';

					foreach ($childbutton['sub_buttons'] as $grandchildbutton)
						echo '
										<li>
											<a href="', $grandchildbutton['href'], '"', isset($grandchildbutton['target']) ? ' target="' . $grandchildbutton['target'] . '"' : '', isset($grandchildbutton['onclick']) ? ' onclick="' . $grandchildbutton['onclick'] . '"' : '', '>
												', $grandchildbutton['title'], !empty($grandchildbutton['amt']) ? ' <span class="amt">' . $grandchildbutton['amt'] . '</span>' : '', '
											</a>
										</li>';

					echo '
									</ul>';
				}

				echo '
								</li>';
			}
			echo '
							</ul>';
		}
		echo '
						</li>';
	}

	echo '
					</ul>
                </div><!-- .menu_nav -->';
}

/**
 * Generate a strip of buttons.
 *
 * @param array $button_strip An array with info for displaying the strip
 * @param string $direction The direction
 * @param array $strip_options Options for the button strip
 */
function template_button_strip($button_strip, $direction = '', $strip_options = array())
{
	global $context, $txt;

	if (!is_array($strip_options))
		$strip_options = array();

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
	{
		// As of 2.1, the 'test' for each button happens while the array is being generated. The extra 'test' check here is deprecated but kept for backward compatibility (update your mods, folks!)
		if (!isset($value['test']) || !empty($context[$value['test']]))
		{
			if (!isset($value['id']))
				$value['id'] = $key;

			$button = '
				<a class="button button_strip_' . $key . (!empty($value['active']) ? ' active' : '') . (isset($value['class']) ? ' ' . $value['class'] : '') . '" ' . (!empty($value['url']) ? 'href="' . $value['url'] . '"' : '') . ' ' . (isset($value['custom']) ? ' ' . $value['custom'] : '') . '>'.(!empty($value['icon']) ? '<span class="main_icons '.$value['icon'].'"></span>' : '').'' . $txt[$value['text']] . '</a>';

			if (!empty($value['sub_buttons']))
			{
				$button .= '
					<div class="top_menu dropmenu ' . $key . '_dropdown">
						<div class="viewport">
							<div class="overview">';
				foreach ($value['sub_buttons'] as $element)
				{
					if (isset($element['test']) && empty($context[$element['test']]))
						continue;

					$button .= '
								<a href="' . $element['url'] . '"><strong>' . $txt[$element['text']] . '</strong>';
					if (isset($txt[$element['text'] . '_desc']))
						$button .= '<br><span>' . $txt[$element['text'] . '_desc'] . '</span>';
					$button .= '</a>';
				}
				$button .= '
							</div><!-- .overview -->
						</div><!-- .viewport -->
					</div><!-- .top_menu -->';
			}

			$buttons[] = $button;
		}
	}

	// No buttons? No button strip either.
	if (empty($buttons))
		return;

	echo '
		<div class="buttonlist', !empty($direction) ? ' float' . $direction : '', '"', (empty($buttons) ? ' style="display: none;"' : ''), (!empty($strip_options['id']) ? ' id="' . $strip_options['id'] . '"' : ''), '>
			', implode('', $buttons), '
		</div>';
}

/**
 * Generate a list of quickbuttons.
 *
 * @param array $list_items An array with info for displaying the strip
 * @param string $list_class Used for integration hooks and as a class name
 * @param string $output_method The output method. If 'echo', simply displays the buttons, otherwise returns the HTML for them
 * @return void|string Returns nothing unless output_method is something other than 'echo'
 */
function template_quickbuttons($list_items, $list_class = null, $output_method = 'echo')
{
	global $txt;

	// Enable manipulation with hooks
	if (!empty($list_class))
		call_integration_hook('integrate_' . $list_class . '_quickbuttons', array(&$list_items));

	// Make sure the list has at least one shown item
	foreach ($list_items as $key => $li)
	{
		// Is there a sublist, and does it have any shown items
		if ($key == 'more')
		{
			foreach ($li as $subkey => $subli)
				if (isset($subli['show']) && !$subli['show'])
					unset($list_items[$key][$subkey]);

			if (empty($list_items[$key]))
				unset($list_items[$key]);
		}
		// A normal list item
		elseif (isset($li['show']) && !$li['show'])
			unset($list_items[$key]);
	}

	// Now check if there are any items left
	if (empty($list_items))
		return;

	// Print the quickbuttons
	$output = '
		<ul class="quickbuttons' . (!empty($list_class) ? ' quickbuttons_' . $list_class : '') . '">';

	// This is used for a list item or a sublist item
	$list_item_format = function($li)
	{
		$html = '
			<li' . (!empty($li['class']) ? ' class="' . $li['class'] . '"' : '') . (!empty($li['id']) ? ' id="' . $li['id'] . '"' : '') . (!empty($li['custom']) ? ' ' . $li['custom'] : '') . '>';

		if (isset($li['content']))
			$html .= $li['content'];
		else
			$html .= '
				<a href="' . (!empty($li['href']) ? $li['href'] : 'javascript:void(0);') . '"' . (!empty($li['javascript']) ? ' ' . $li['javascript'] : '') . '>
					' . (!empty($li['icon']) ? '<span class="main_icons ' . $li['icon'] . '"></span>' : '') . (!empty($li['label']) ? $li['label'] : '') . '
				</a>';

		$html .= '
			</li>';

		return $html;
	};

	foreach ($list_items as $key => $li)
	{
		// Handle the sublist
		if ($key == 'more')
		{
			$output .= '
			<li class="post_options">
				<a href="javascript:void(0);">' . $txt['post_options'] . '</a>
				<ul>';

			foreach ($li as $subli)
				$output .= $list_item_format($subli);

			$output .= '
				</ul>
			</li>';
		}
		// Ordinary list item
		else
			$output .= $list_item_format($li);
	}

	$output .= '
		</ul><!-- .quickbuttons -->';

	// There are a few spots where the result needs to be returned
	if ($output_method == 'echo')
		echo $output;
	else
		return $output;
}

/**
 * The upper part of the maintenance warning box
 */
function template_maint_warning_above()
{
	global $txt, $context, $scripturl;

	echo '
	<div class="errorbox" id="errors">
		<dl>
			<dt>
				<strong id="error_serious">', $txt['forum_in_maintenance'], '</strong>
			</dt>
			<dd class="error" id="error_list">
				', sprintf($txt['maintenance_page'], $scripturl . '?action=admin;area=serversettings;' . $context['session_var'] . '=' . $context['session_id']), '
			</dd>
		</dl>
	</div>';
}

/**
 * The lower part of the maintenance warning box.
 */
function template_maint_warning_below()
{

}

?>